@@ -1,7 +1,7 @@
 package Bencher::Scenario::RangeIterators::Create;
 
 our $DATE = '2019-04-23'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $scenario = {
     summary => 'Benchmark iterator creation',
@@ -27,7 +27,7 @@ Bencher::Scenario::RangeIterators::Create - Benchmark iterator creation
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::RangeIterators::Create (from Perl distribution Bencher-Scenarios-RangeIterators), released on 2019-04-23.
+This document describes version 0.003 of Bencher::Scenario::RangeIterators::Create (from Perl distribution Bencher-Scenarios-RangeIterators), released on 2019-04-23.
 
 =head1 SYNOPSIS
 
@@ -49,11 +49,11 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Range::Iterator> 0.001
+L<Range::Iterator> 0.002
 
-L<Range::Iter> 0.001
+L<Range::Iter> 0.002
 
-L<Range::ArrayIter> 0.001
+L<Range::ArrayIter> 0.002
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -95,9 +95,9 @@ Benchmark with default options (C<< bencher -m RangeIterators::Create >>):
  +------------------+-----------+-----------+------------+---------+---------+
  | participant      | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +------------------+-----------+-----------+------------+---------+---------+
- | Range::ArrayIter |    170000 |       5.7 |        1   | 6.7e-09 |      20 |
- | Range::Iterator  |    250000 |       4   |        1.4 | 6.7e-09 |      20 |
- | Range::Iter      |    280000 |       3.5 |        1.6 |   5e-09 |      20 |
+ | Range::ArrayIter |    330000 |     3     |      1     | 3.3e-09 |      21 |
+ | Range::Iterator  |    606400 |     1.649 |      1.811 | 5.8e-11 |      20 |
+ | Range::Iter      |    700000 |     1.4   |      2.1   | 5.4e-09 |      20 |
  +------------------+-----------+-----------+------------+---------+---------+
 
 
