@@ -1,7 +1,7 @@
 package Bencher::Scenario::RangeIterators::Iterate;
 
 our $DATE = '2019-04-23'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -34,7 +34,7 @@ Bencher::Scenario::RangeIterators::Iterate - Benchmark iteration
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::RangeIterators::Iterate (from Perl distribution Bencher-Scenarios-RangeIterators), released on 2019-04-23.
+This document describes version 0.003 of Bencher::Scenario::RangeIterators::Iterate (from Perl distribution Bencher-Scenarios-RangeIterators), released on 2019-04-23.
 
 =head1 SYNOPSIS
 
@@ -56,11 +56,11 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Range::Iterator> 0.001
+L<Range::Iterator> 0.002
 
-L<Range::Iter> 0.001
+L<Range::Iter> 0.002
 
-L<Range::ArrayIter> 0.001
+L<Range::ArrayIter> 0.002
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -107,13 +107,13 @@ Run on: perl: I<< v5.26.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (
 Benchmark with default options (C<< bencher -m RangeIterators::Iterate >>):
 
  #table1#
- +------------------+-----------+-----------+------------+-----------+---------+
- | participant      | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
- +------------------+-----------+-----------+------------+-----------+---------+
- | Range::ArrayIter |       9.6 |     100   |       1    |   0.00012 |      20 |
- | Range::Iterator  |      20   |      49   |       2.1  | 7.5e-05   |      20 |
- | Range::Iter      |      61.7 |      16.2 |       6.44 | 1.1e-05   |      20 |
- +------------------+-----------+-----------+------------+-----------+---------+
+ +------------------+-----------+-----------+------------+---------+---------+
+ | participant      | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +------------------+-----------+-----------+------------+---------+---------+
+ | Range::ArrayIter |      9.83 |     102   |       1    | 6.7e-05 |      20 |
+ | Range::Iterator  |     20.5  |      48.7 |       2.09 | 2.7e-05 |      21 |
+ | Range::Iter      |     63.4  |      15.8 |       6.46 | 1.1e-05 |      20 |
+ +------------------+-----------+-----------+------------+---------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
