@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::RangeIterators::Create;
 
-our $VERSION = 0.002; # VERSION
+our $VERSION = 0.003; # VERSION
 
 our $results = [
   [
@@ -8,28 +8,28 @@ our $results = [
     "OK",
     [
       {
-        errors => 6.7e-09,
+        errors => 3.3e-09,
         participant => "Range::ArrayIter",
-        rate => 170000,
-        samples => 20,
-        time => 5.7,
+        rate => 330000,
+        samples => 21,
+        time => 3,
         vs_slowest => 1,
       },
       {
-        errors => 6.7e-09,
+        errors => 5.8e-11,
         participant => "Range::Iterator",
-        rate => 250000,
+        rate => 606400,
         samples => 20,
-        time => 4,
-        vs_slowest => 1.4,
+        time => 1.649,
+        vs_slowest => 1.811,
       },
       {
-        errors => 5e-09,
+        errors => 5.4e-09,
         participant => "Range::Iter",
-        rate => 280000,
+        rate => 700000,
         samples => 20,
-        time => 3.5,
-        vs_slowest => 1.6,
+        time => 1.4,
+        vs_slowest => 2.1,
       },
     ],
     {
@@ -133,7 +133,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3289.965,
+                                              speed                        => 3275.018,
                                               stepping                     => 7,
                                             },
                                             {
@@ -228,7 +228,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3284.857,
+                                              speed                        => 3295.263,
                                               stepping                     => 7,
                                             },
                                             {
@@ -323,7 +323,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 3298.291,
+                                              speed                        => 3288.641,
                                               stepping                     => 7,
                                             },
                                             {
@@ -418,11 +418,11 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3290.155,
+                                              speed                        => 3294.506,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.0857729911804199,
+      "func.elapsed_time"              => 0.0925209522247314,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__"                               => 1.041,
@@ -430,9 +430,9 @@ our $results = [
                                             "Benchmark::Dumb"                           => 0.111,
                                             "Devel::Platform::Info"                     => 0.16,
                                             "perl"                                      => "v5.26.0",
-                                            "Range::ArrayIter"                          => 0.001,
-                                            "Range::Iter"                               => 0.001,
-                                            "Range::Iterator"                           => 0.001,
+                                            "Range::ArrayIter"                          => 0.002,
+                                            "Range::Iter"                               => 0.002,
+                                            "Range::Iterator"                           => 0.002,
                                             "Sys::Info"                                 => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
@@ -466,9 +466,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1555994658,
       "func.scenario_module_sha1sum"   => "f3f392dddd479900590f5bdec53f2f6a066c6375",
       "func.scenario_module_sha256sum" => "de6fe548b2ccec21a623587a378c81cc583679a7a5076d8459b9c012feed60e6",
-      "func.time_end"                  => 1555994797.37368,
+      "func.time_end"                  => 1555996955.50484,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1555994797.28791,
+      "func.time_start"                => 1555996955.41232,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "\x{3BC}s"],
       "table.fields"                   => [
