@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::RangeIterators::Iterate;
 
-our $VERSION = 0.002; # VERSION
+our $VERSION = 0.003; # VERSION
 
 our $results = [
   [
@@ -8,28 +8,28 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.00012,
+        errors => 6.7e-05,
         participant => "Range::ArrayIter",
-        rate => 9.6,
+        rate => 9.83,
         samples => 20,
-        time => 100,
+        time => 102,
         vs_slowest => 1,
       },
       {
-        errors => 7.5e-05,
+        errors => 2.7e-05,
         participant => "Range::Iterator",
-        rate => 20,
-        samples => 20,
-        time => 49,
-        vs_slowest => 2.1,
+        rate => 20.5,
+        samples => 21,
+        time => 48.7,
+        vs_slowest => 2.09,
       },
       {
         errors => 1.1e-05,
         participant => "Range::Iter",
-        rate => 61.7,
+        rate => 63.4,
         samples => 20,
-        time => 16.2,
-        vs_slowest => 6.44,
+        time => 15.8,
+        vs_slowest => 6.46,
       },
     ],
     {
@@ -133,7 +133,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3261.206,
+                                              speed                        => 3296.588,
                                               stepping                     => 7,
                                             },
                                             {
@@ -228,7 +228,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3286.749,
+                                              speed                        => 3296.398,
                                               stepping                     => 7,
                                             },
                                             {
@@ -323,7 +323,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => "3286.370",
+                                              speed                        => 3276.153,
                                               stepping                     => 7,
                                             },
                                             {
@@ -418,11 +418,11 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3294.885,
+                                              speed                        => 3292.425,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 3.7874219417572,
+      "func.elapsed_time"              => 4.03993010520935,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__"                                => 1.041,
@@ -430,9 +430,9 @@ our $results = [
                                             "Benchmark::Dumb"                            => 0.111,
                                             "Devel::Platform::Info"                      => 0.16,
                                             "perl"                                       => "v5.26.0",
-                                            "Range::ArrayIter"                           => 0.001,
-                                            "Range::Iter"                                => 0.001,
-                                            "Range::Iterator"                            => 0.001,
+                                            "Range::ArrayIter"                           => 0.002,
+                                            "Range::Iter"                                => 0.002,
+                                            "Range::Iterator"                            => 0.002,
                                             "Sys::Info"                                  => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
@@ -466,9 +466,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1555994694,
       "func.scenario_module_sha1sum"   => "30606d41566df5368c3348bb6d379bf41fdb12b7",
       "func.scenario_module_sha256sum" => "073e9b1a722adb34d8668e570adf188eb6e2253ca735d13bf8e3245888ce575a",
-      "func.time_end"                  => 1555994801.568,
+      "func.time_end"                  => 1555996959.9488,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1555994797.78058,
+      "func.time_start"                => 1555996955.90887,
       "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, "/s", "ms"],
       "table.fields"                   => ["participant", "rate", "time", "vs_slowest", "errors", "samples"],
