@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::RangeIterators::Startup;
 
-our $VERSION = 0.002; # VERSION
+our $VERSION = 0.003; # VERSION
 
 our $results = [
   [
@@ -8,36 +8,36 @@ our $results = [
     "OK",
     [
       {
-        errors => 1.3e-05,
-        mod_overhead_time => 3.32,
+        errors => 8.5e-06,
+        mod_overhead_time => 4.6,
         participant => "Range::ArrayIter",
         samples => 20,
-        time => 9.2,
+        time => 10.4,
         vs_slowest => 1,
       },
-      {
-        errors => 3.4e-06,
-        mod_overhead_time => 3.14,
-        participant => "Range::Iter",
-        samples => 20,
-        time => 9.02,
-        vs_slowest => 1.02,
-      },
       {
         errors => 8.7e-06,
-        mod_overhead_time => 2.62,
+        mod_overhead_time => 4.6,
         participant => "Range::Iterator",
-        samples => 20,
-        time => 8.5,
-        vs_slowest => 1.1,
+        samples => 21,
+        time => 10.4,
+        vs_slowest => 1.01,
       },
       {
-        errors => 5.8e-06,
+        errors => 1.8e-05,
+        mod_overhead_time => 4.2,
+        participant => "Range::Iter",
+        samples => 21,
+        time => 10,
+        vs_slowest => 1,
+      },
+      {
+        errors => 1.2e-05,
         mod_overhead_time => 0,
         participant => "perl -e1 (baseline)",
         samples => 20,
-        time => 5.88,
-        vs_slowest => 1.56,
+        time => 5.8,
+        vs_slowest => 1.8,
       },
     ],
     {
@@ -141,7 +141,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3271.612,
+                                              speed                        => 3290.155,
                                               stepping                     => 7,
                                             },
                                             {
@@ -236,7 +236,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3261.962,
+                                              speed                        => 3258.557,
                                               stepping                     => 7,
                                             },
                                             {
@@ -331,7 +331,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 3265.557,
+                                              speed                        => 3266.693,
                                               stepping                     => 7,
                                             },
                                             {
@@ -426,11 +426,11 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3291.857,
+                                              speed                        => "3286.370",
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.927616119384766,
+      "func.elapsed_time"              => 0.975898027420044,
       "func.module_startup"            => 1,
       "func.module_versions"           => {
                                             "__PACKAGE__"                                => 1.041,
@@ -438,9 +438,9 @@ our $results = [
                                             "Benchmark::Dumb"                            => 0.111,
                                             "Devel::Platform::Info"                      => 0.16,
                                             "perl"                                       => "v5.26.0",
-                                            "Range::ArrayIter"                           => 0.001,
-                                            "Range::Iter"                                => 0.001,
-                                            "Range::Iterator"                            => 0.001,
+                                            "Range::ArrayIter"                           => 0.002,
+                                            "Range::Iter"                                => 0.002,
+                                            "Range::Iterator"                            => 0.002,
                                             "Sys::Info"                                  => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
@@ -474,9 +474,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1555994658,
       "func.scenario_module_sha1sum"   => "d0bb8094f265edb8e987d9af6850a0541f839b04",
       "func.scenario_module_sha256sum" => "4e3e7cd75dbcf631ab267f423e1673317d692d311838c4700a76178f20302ede",
-      "func.time_end"                  => 1555994802.71215,
+      "func.time_end"                  => 1555996961.14898,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1555994801.78453,
+      "func.time_start"                => 1555996960.17308,
       "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, "ms", "ms"],
       "table.fields"                   => [
